Security Advisories (3)
CPANSA-Jifty-2011-01 (2011-03-17)

The path as passed in the fragment request data structure was used verbatim in the dispatcher and other locations. This possibly allowed requests to walk around ACLs by requesting '/some/safe/place/../../../dangerous' as a fragment.

CPANSA-Jifty-2009-01 (2009-04-09)

The REST plugin would let you call any method on the model.

CPANSA-Jifty-2008-01 (2009-04-08)

Allowed all actions on GET.

NAME

Jifty::Web::Session::ClientSide - Session handler for client-side sessions

SYNOPSIS

In your etc/config.yml:

framework:
  Web:
    SessionClass: Jifty::Web::Session::ClientSide
    SessionSecret: secret_passphrase

new

Returns a new, empty session handler, subclassing Jifty::Web::Session.

_cipher

Accessor to the underlying Crypt::CBC object that encapsulates the server-side secret.

id

Returns the session's id if it has been loaded, or undef otherwise.

load [ID]

Load up the current session from the given ID, or the appropriate cookie (see "cookie_name" in Jifty::Web::Session) otherwise.

If both of those fail, creates a session in memory.

get KEY [TYPE]

See "get" in Jifty::Web::Session.

set KEY => VALUE, [TYPE]

See "set" in Jifty::Web::Session.

remove KEY, [TYPE]

See "remove" in Jifty::Web::Session.

continuations

See "continuations" in Jifty::Web::Session.

unload

See "unload" in Jifty::Web::Session.

flush

Outputs the client-side session as one or more cookies.